PySense
=======

## Start PySense Daemon

To start daemon execute the `pysense` command.

In the first run, pysense will create a directory `.sense` in
the user home.

## The think client

### Memories

To set a

## Thoughts Sources

PySense can get thoughts direct from git repositories.

You can fetch new Thoughts: `think learn`
